pub struct HeapStats {
pub region_stats: [Option<RegionStats>; 3],
pub size: usize,
pub current_usage: usize,
}Expand description
Stats for a heap allocator
Enable the “internal-heap-stats” feature if you want collect additional heap informations at the cost of extra cpu time during every alloc/dealloc.
Fields
region_stats: [Option<RegionStats>; 3]Granular stats for all the configured memory regions.
size: usizeTotal size of all combined heap regions in bytes.
current_usage: usizeCurrent usage of the heap across all configured regions in bytes.