pub struct RegionStats {
pub size: usize,
pub used: usize,
pub free: usize,
pub capabilities: EnumSet<MemoryCapability>,
}Expand description
Stats for a heap region
Fields
size: usizeTotal usable size of the heap region in bytes.
used: usizeCurrently used size of the heap region in bytes.
free: usizeFree size of the heap region in bytes.
capabilities: EnumSet<MemoryCapability>Capabilities of the memory region.